==> apache-groovy-src-2.5.23.zip: groovy-2.5.23/src/main/java/org/codehaus/groovy/reflection/stdclasses/BigDecimalCachedClass.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.codehaus.groovy.reflection.stdclasses;

import org.codehaus.groovy.reflection.ClassInfo;

import java.math.BigDecimal;
import java.math.BigInteger;

public class BigDecimalCachedClass extends DoubleCachedClass {
    public BigDecimalCachedClass(Class klazz, ClassInfo classInfo) {
        super(klazz, classInfo, true);
    }

    public boolean isDirectlyAssignable(Object argument) {
        return argument instanceof BigDecimal;
    }

    public Object coerceArgument(Object argument) {
        if (argument instanceof BigDecimal) {
            return argument;
        } else if (argument instanceof Long) {
            return new BigDecimal((Long) argument);
        } else if (argument instanceof BigInteger) {
            return new BigDecimal((BigInteger) argument);
        }

        if (argument instanceof Number) {
            return new BigDecimal(((Number) argument).doubleValue());
        }
        return argument;
    }
}

==> apache-groovy-src-3.0.25.zip: groovy-3.0.25/src/main/java/org/codehaus/groovy/reflection/stdclasses/BigDecimalCachedClass.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.codehaus.groovy.reflection.stdclasses;

import org.codehaus.groovy.reflection.ClassInfo;
import org.codehaus.groovy.runtime.typehandling.NumberMath;

import java.math.BigDecimal;

public class BigDecimalCachedClass extends DoubleCachedClass {
    public BigDecimalCachedClass(Class klazz, ClassInfo classInfo) {
        super(klazz, classInfo, true);
    }

    public boolean isDirectlyAssignable(Object argument) {
        return argument instanceof BigDecimal;
    }

    public Object coerceArgument(Object argument) {
        if (argument instanceof Number) {
            return NumberMath.toBigDecimal((Number) argument);
        }
        return argument;
    }
}
